@@ -5,6 +5,7 @@ from cowait.types import serialize
 from .definition import TaskDefinition
 from .components import TaskManager, RpcComponent, rpc
 from .parent_task import ParentTask
+from .errors import StoppedError
 
 
 class Task(object):
@@ -179,6 +180,9 @@ class Task(object):
 
         return task
 
+    def exit(self, result):
+        raise StoppedError(result)
+
     @staticmethod
     def get_current() -> 'Task':
         return Task.__current__
